declare const alphabetByEncoding: Record<string, number>;
declare const alphabetByValue: Array<string>;
declare const bitsPerLetter = 6;
declare const bitsPerByte = 8;
declare const maxLetterValue = 63;
export { alphabetByEncoding, alphabetByValue, bitsPerLetter, bitsPerByte, maxLetterValue };
