/**
 * Converts a Uint8Array of binary data or a utf-8 string to a base-64 encoded string.
 *
 * @param _input - the binary data or string to encode.
 * @returns base64 string.
 *
 * @see https://tools.ietf.org/html/rfc4648#section-4
 */
export declare function toBase64(_input: Uint8Array | string): string;
