/**
 * Converts a Uint8Array of binary data or a utf-8 string to a base-64 encoded string using
 * Node.JS's `buffer` module.
 *
 * @param _input - the binary data or string to encode.
 * @returns base64 string.
 */
export declare const toBase64: (_input: Uint8Array | string) => string;
